@@ -11,7 +11,7 @@ import sys
 
 import pytest
 
-from autogen.import_utils import skip_on_missing_imports
+from autogen.import_utils import run_for_optional_imports
 
 here = os.path.abspath(os.path.dirname(__file__))
 
@@ -44,111 +44,109 @@ def run_notebook(input_nb, output_nb="executed_openai_notebook.ipynb", save=Fals
                 nbformat.write(nb, nb_executed_file)
 
 
-@pytest.mark.openai
 @pytest.mark.skipif(
     not sys.version.startswith("3.13"),
     reason="do not run if py!=3.13",
 )
-@skip_on_missing_imports(["openai"])
+@run_for_optional_imports(["openai"], "openai")
 def test_agentchat_auto_feedback_from_code(save=False):
     run_notebook("agentchat_auto_feedback_from_code_execution.ipynb", save=save)
 
 
-@pytest.mark.openai
 @pytest.mark.skipif(
     not sys.version.startswith("3.11"),
     reason="do not run if py!=3.11",
 )
-@skip_on_missing_imports(["openai"])
+@run_for_optional_imports(["openai"], "openai")
 def _test_oai_completion(save=False):
     run_notebook("oai_completion.ipynb", save=save)
 
 
-@pytest.mark.openai
 @pytest.mark.skipif(
     not sys.version.startswith("3.12"),
     reason="do not run if py!=3.12",
 )
-@skip_on_missing_imports(["openai"])
+@run_for_optional_imports(["openai"], "openai")
 def test_agentchat_function_call(save=False):
     run_notebook("agentchat_function_call.ipynb", save=save)
 
 
-@pytest.mark.openai
 @pytest.mark.skipif(
     not sys.version.startswith("3.10"),
     reason="do not run if py!=3.10",
 )
-@skip_on_missing_imports(["openai"])
+@run_for_optional_imports(["openai"], "openai")
 def test_agentchat_function_call_currency_calculator(save=False):
     run_notebook("agentchat_function_call_currency_calculator.ipynb", save=save)
 
 
-@pytest.mark.openai
 @pytest.mark.skipif(
     not sys.version.startswith("3.13"),
     reason="do not run if py!=3.13",
 )
-@skip_on_missing_imports(["openai"])
+@run_for_optional_imports(["openai"], "openai")
 def test_agentchat_function_call_async(save=False):
     run_notebook("agentchat_function_call_async.ipynb", save=save)
 
 
-@pytest.mark.openai
 @pytest.mark.skipif(
     not sys.version.startswith("3.12"),
     reason="do not run if py!=3.12",
 )
-@skip_on_missing_imports(["openai"])
+@run_for_optional_imports(["openai"], "openai")
 def _test_agentchat_MathChat(save=False):  # noqa: N802
     run_notebook("agentchat_MathChat.ipynb", save=save)
 
 
-@pytest.mark.openai
 @pytest.mark.skipif(
     not sys.version.startswith("3.10"),
     reason="do not run if py!=3.10",
 )
-@skip_on_missing_imports(["openai"])
+@run_for_optional_imports(["openai"], "openai")
 def _test_oai_chatgpt_gpt4(save=False):
     run_notebook("oai_chatgpt_gpt4.ipynb", save=save)
 
 
-@pytest.mark.openai
 @pytest.mark.skipif(
     not sys.version.startswith("3.12"),
     reason="do not run if py!=3.12",
 )
-@skip_on_missing_imports(["openai"])
+@run_for_optional_imports(["openai"], "openai")
 def test_agentchat_groupchat_finite_state_machine(save=False):
     run_notebook("agentchat_groupchat_finite_state_machine.ipynb", save=save)
 
 
-@pytest.mark.openai
 @pytest.mark.skipif(
     not sys.version.startswith("3.11"),
     reason="do not run if py!=3.11",
 )
-@skip_on_missing_imports(["openai"])
+@run_for_optional_imports(["openai"], "openai")
 def test_agentchat_cost_token_tracking(save=False):
     run_notebook("agentchat_cost_token_tracking.ipynb", save=save)
 
 
-@pytest.mark.openai
 @pytest.mark.skipif(
     not sys.version.startswith("3.11"),
     reason="do not run if py!=3.11",
 )
-@skip_on_missing_imports(["openai"])
+@run_for_optional_imports(["openai"], "openai")
 def test_agentchat_groupchat_stateflow(save=False):
     run_notebook("agentchat_groupchat_stateflow.ipynb", save=save)
 
 
-if __name__ == "__main__":
-    # test_agentchat_auto_feedback_from_code(save=True)
-    # test_oai_chatgpt_gpt4(save=True)
-    # test_oai_completion(save=True)
-    # test_agentchat_MathChat(save=True)
-    # test_agentchat_function_call(save=True)
-    # test_graph_modelling_language_using_select_speaker(save=True)
-    test_agentchat_function_call_async(save=True)
+@pytest.mark.skipif(
+    not sys.version.startswith("3.13"),
+    reason="do not run if py!=3.13",
+)
+@run_for_optional_imports(["openai"], "openai")
+def test_agentchat_grok_sbom_analysisw(save=False):
+    run_notebook("agentchat_grok_sbom_analysis.ipynb", save=save)
+
+
+@pytest.mark.skipif(
+    not sys.version.startswith("3.13"),
+    reason="do not run if py!=3.13",
+)
+@run_for_optional_imports(["openai"], "openai")
+def test_agentchat_gpt_5_verbosity_example(save=False):
+    run_notebook("agentchat_gpt-5_verbosity_example.ipynb", save=save)
